/*
  * Motif Tools Library, Version 3.1
  * $Id: Progress.h,v 1.1 2001/07/20 23:03:48 grmcdorman Exp $
  *
  * Written by Grant McDorman
  * Copyright (c) 2001 by Grant McDorman
  *
  * This is open source software.  See the file LICENSE for details.
  * There is no warranty for this software.  See NO_WARRANTY for details.
  *
  * $Log: Progress.h,v $
  * Revision 1.1  2001/07/20 23:03:48  grmcdorman
  * This adds the Progress widget to Xmt.
  *
  *
  */

#ifndef _XmtProgress_h
#define _XmtProgress_h    

#include <Xm/Xm.h>

/*
 * Progress Widget provides a vertical or horizontal progress bar.
 *
 * Resources
 * 
 * Name         Class       Type            Default         Access
 * fillColor    Foreground  Pixel           Dynamic         CSG
 * fontList     FontList    XmFont          XtDefaultFont   CSG
 * labelBoxed   LabelBoxed  Boolean         False           CSG
 * labelString  LabelString XmString        NULL            CSG
 * labelXOR     LabelXOR    Boolean         False           CSG
 * margin       Margin      Dimension       2               CSG
 * orientation  Orientation unsigned char   XmHORIZONTAL    CSG
 * renderTable  RenderTable XmRenderTable   dynamic         CSG (MOTIF 2.0+)
 * reverse      Reverse     Boolean         False           CSG
 * showPercent  ShowPercent Boolean         dynamic         CSG
 * stepSpacing  StepSpacing Dimension       2               CSG
 * stepWidth    StepWidth   Dimension       dynamic         CSG
 * style        Style       XmtProgressStyle XmtCONTINUOUS  CSG
 * value        Value       int             0               CSG
 *
 * fillColor: highlight colour for fill
 * labelBoxed: draw label in a box (actually, XmStringDrawImage)
 * labelString: string to draw if showPercent False; can be NULL
 * labelXOR: draw label using XOR function
 * margin: edge margins
 * orientation: XmHORIZONTAL or XmVERTICAL. Ignored if style is XmPROGRESS_CIRCLE.
 * reverse: Reverse direction; for horizontal, sweep from right to left;
 *          for vertical, sweep from ?; for circle, sweep counter-clockwise.
 * showPercent: Show percentage value, centered in widget.
 * stepWidth: for XmPROGRESS_STEPPED only, width of one step.
 * stepSpacing: for XmPROGRESS_STEPPED only, spacing between step boxes.
 * style: XmtPROGRESS_CONTINUOUS, XmtPROGRESS_STEPPED, or XmtPROGRESS_CIRCLE.
 * value: 0-XmtPROGRESS_MAX. Currently decipercents (percent*100).
 */

externalref WidgetClass xmtProgressWidgetClass;
typedef struct _XmtProgressClassRec *XmtProgressWidgetClass;
typedef struct _XmtProgressRec *XmtProgressWidget;



externalref _Xconst char XmtProgressStrings[];
/*
 * Duplicate the Xm resources as 'Xmt' for consistency. We accept
 * either, though.
 */
#ifndef XmtNfillColor
#define XmtNfillColor ((char*)&XmtProgressStrings[0])
#endif
#ifndef XmtNfontList
#define XmtNfontList ((char*)&XmtProgressStrings[10])
#endif
#ifndef XmtNlabelBoxed
#define XmtNlabelBoxed ((char*)&XmtProgressStrings[19])
#endif
#ifndef XmtNlabelString
#define XmtNlabelString ((char*)&XmtProgressStrings[30])
#endif
#ifndef XmtNlabelXOR
#define XmtNlabelXOR ((char*)&XmtProgressStrings[42])
#endif
#ifndef XmtNmargin
#define XmtNmargin ((char*)&XmtProgressStrings[51])
#endif
#ifndef XmtNorientation
#define XmtNorientation ((char*)&XmtProgressStrings[58])
#endif

#if XmVersion >= 2000
#ifndef XmtNrenderTable
#define XmtNrenderTable ((char*)&XmtProgressStrings[70])
#endif
#endif

#ifndef XmtNreverse
#define XmtNreverse ((char*)&XmtProgressStrings[82])
#endif
#ifndef XmtNshowPercent
#define XmtNshowPercent ((char*)&XmtProgressStrings[90])
#endif
#ifndef XmtNstepSpacing
#define XmtNstepSpacing ((char*)&XmtProgressStrings[102])
#endif
#ifndef XmtNstepWidth
#define XmtNstepWidth ((char*)&XmtProgressStrings[114])
#endif

#ifndef XmtNstyle
#define XmtNstyle ((char*)&XmtProgressStrings[124])
#endif
#ifndef XmtNvalue
#define XmtNvalue ((char*)&XmtProgressStrings[130])
#endif

#ifndef XmtCLabelBoxed
#define XmtCLabelBoxed ((char*)&XmtProgressStrings[136])
#endif
#ifndef XmtCLabelString
#define XmtCLabelString ((char*)&XmtProgressStrings[147])
#endif
#ifndef XmtCLabelXOR
#define XmtCLabelXOR ((char*)&XmtProgressStrings[159])
#endif
#ifndef XmtCMargin
#define XmtCMargin ((char*)&XmtProgressStrings[168])
#endif
#ifndef XmtCOrientation
#define XmtCOrientation ((char*)&XmtProgressStrings[175])
#endif
#ifndef XmtCReverse
#define XmtCReverse ((char*)&XmtProgressStrings[187])
#endif
#ifndef XmtCShowPercent
#define XmtCShowPercent ((char*)&XmtProgressStrings[195])
#endif
#ifndef XmtCStepSpacing
#define XmtCStepSpacing ((char*)&XmtProgressStrings[207])
#endif
#ifndef XmtCStepWidth
#define XmtCStepWidth ((char*)&XmtProgressStrings[219])
#endif
#ifndef XmtCStyle
#define XmtCStyle ((char*)&XmtProgressStrings[229])
#endif
#ifndef XmtCValue
#define XmtCValue ((char*)&XmtProgressStrings[235])
#endif
#ifndef XmtRProgressStyle
#define XmtRProgressStyle ((char*)&XmtProgressStrings[241])
#endif

/*
 * Style definitions
 */
typedef enum {
    XmtPROGRESS_CONTINUOUS,      /* continuous bar */
    XmtPROGRESS_STEPPED,         /* stepped, in the style of M* W*n*d*ws */
    XmtPROGRESS_CIRCLE           /* as a circle */
} XmtProgressStyle;

#define XmtPROGRESS_MAX 10000   /* deci-percent [percent * 100] */

_XFUNCPROTOBEGIN
#if NeedFunctionPrototypes
extern void XmtProgressClear(Widget);       /* same as XmtProgressSet(w, 0) */
extern void XmtProgressSet(Widget, int);
extern int  XmtProgressGet(Widget);
extern Widget XmtCreateProgress(Widget, String, ArgList, Cardinal);
#else
extern void XmtProgressClear();
extern void XmtProgressSet();
extern int  XmtProgressGet();
extern Widget XmtCreateProgress();
#endif

_XFUNCPROTOEND

#endif /* _XmtProgress_h */
